Cascades<-local({
  con<-textConnection('
    name          n  mean     t       t_3     t_4     t_5
    350304        98  19.685  0.1209  0.0488  0.1433 -0.0004
    351433        59  62.580  0.0915  0.0105  0.1569  0.0020
    351862        90  40.852  0.1124  0.0614  0.1541 -0.0058
    351897        61  46.045  0.1032  0.0417  0.1429 -0.0022
    352997        65  45.021  0.0967 -0.0134  0.1568  0.0173
    353445        86  31.042  0.1328 -0.0176  0.1206  0.0235
    353770        78  80.143  0.1008  0.0943  0.1967  0.0856
    356907        72  41.305  0.1143  0.0555  0.1210  0.0487
    357169        67  30.585  0.1107  0.0478  0.1371  0.0316
    357331        99  32.932  0.1179  0.0492  0.0900  0.0225
    357354        49  17.560  0.1308  0.0940  0.1273  0.0352
    358466        61  69.518  0.1119 -0.0429  0.0927 -0.0061
    450945        69  47.653  0.1018  0.0435  0.1446 -0.0056
    451233        73 102.501  0.1025  0.0182  0.1047 -0.0221
    453284        70  52.413  0.1054 -0.0224  0.1664  0.0035
    454764        66  79.696  0.1174  0.0124  0.1317 -0.0176
    454769        59  44.643  0.1115 -0.0346  0.1032  0.0083
    457773        74  58.655  0.1003  0.0446  0.1450 -0.0379
    458773        82  39.024  0.1046  0.0128  0.1583  0.0443
  ')
  temp<-read.table(con,header=TRUE,colClasses=c('character',rep('numeric',6)))
  close(con)
  #as.regdata(temp) # not allowed -- can't assume that package is laoded
  structure(temp, class=c("regdata",class(temp)))
})
